@@ -238,7 +238,7 @@ class A2P2ClientPreferences():
             p=A2P2ClientPreferences()
             versionInPref=p.getA2P2Version()
             if __version__ != versionInPref:
-                print(f"💡 You may try to backup this file (V{versionInPref}) and merge with a new generated one for V{__version__}.")
+                print(f"HINT: You may try to backup this file (V{versionInPref}) and merge with a new generated one for V{__version__}.")
         else:
             import getpass
 
@@ -248,7 +248,7 @@ class A2P2ClientPreferences():
             config['a2p2'] = {}
             s = config['a2p2']
             s['# A2P2 SECTION'] = ""
-            s['# = > please do not modify next properties unless you handle the possible cAtAstrOphE 🔥 ? <'] = ""
+            s['# = > please do not modify next properties <'] = ""
             s['version'] = __version__
 
 
@@ -259,6 +259,13 @@ class A2P2ClientPreferences():
             s['#login'] = "my.email@my.lab"
             s['#password'] = "12345zZ"
 
+            config['chara'] = {}
+            s = config['chara']
+            s['# CHARA SECTION'] = ""
+            s['# = > please uncomment and update next properties to make it active <'] = ""
+            s['# = > queueserver may be uncommented to forward OB to a remote server instead <'] = ""
+            s['#queueserver'] = "http://localhost:2468/test"
+
             config['p2'] = {}
             s=config['p2']
             s['# ESO P2 SECTION'] = ""
@@ -314,6 +321,10 @@ class A2P2ClientPreferences():
     def getJmmcPassword(self):
         return self.getConfig("jmmc", "password", None)
 
+    # Retrieve CHARA prefs
+    def getCharaQueueServer(self):
+        return self.getConfig("chara", "queueserver", None)
+
 
     # Retrieve P2 prefs
     def getP2Username(self):
