@@ -14,10 +14,12 @@ FIXTURE_DIR = os.path.join( os.path.dirname(os.path.realpath(__file__)) )
 
 @pytest.mark.datafiles(
     os.path.join(FIXTURE_DIR,"aspro-sample-bad-coords.obxml"),
-    os.path.join(FIXTURE_DIR,"aspro-sample-bad-k.obxml"),
-    os.path.join(FIXTURE_DIR,"aspro-sample.obxml"),
-    os.path.join(FIXTURE_DIR,"aspro-sample-bad-insmode.obxml"),
+    #os.path.join(FIXTURE_DIR,"aspro-sample-bad-k.obxml"),
+    #os.path.join(FIXTURE_DIR,"aspro-sample.obxml"),
+    #os.path.join(FIXTURE_DIR,"aspro-sample-bad-insmode.obxml"),
+    os.path.join(FIXTURE_DIR,"SCI_1Aur_SPICA_S1S2W1W2E1E2_LR_FT_2021-10-01.obxml"),
 )
+
 def test_obxml_value_error(datafiles):
     a2p2c=A2p2Client(True)
 
@@ -28,8 +30,10 @@ def test_obxml_value_error(datafiles):
         print("> ERROR log for %s"+ file)
         print(errorLog)
         print("< ERROR log \n\n")
-
-        assert "Value error" in errorLog
+        if "bad" in file:
+            assert "Value error" in errorLog
+        else:
+            assert "Value error" not in errorLog
 
 def processOB(a2p2c, file):
     print("checking OB at %s location" % file)
@@ -37,7 +41,10 @@ def processOB(a2p2c, file):
     for obsc in ob.observationConfiguration:
         print("obsConfig.id=%s" % obsc.id)
     for obss in ob.observationSchedule.OB:
-        print("obsSchedule.ref=%s" % str(obss.ref))
+        if "ref" in obss:
+            print("obsSchedule.ref=%s" % str(obss.ref))
+        else:
+            print("no obsSchedule.ref")
     #    print(ob)
     print("\n\n")
     a2p2c.clearErrors()
